@@ -1,13 +1,10 @@
-require "observer"
-
 module FactoryBot
   class Evaluation
-    include Observable
-
-    def initialize(evaluator, attribute_assigner, to_create)
+    def initialize(evaluator, attribute_assigner, to_create, observer)
       @evaluator = evaluator
       @attribute_assigner = attribute_assigner
       @to_create = to_create
+      @observer = observer
     end
 
     delegate :object, :hash, to: :@attribute_assigner
@@ -20,8 +17,7 @@ module FactoryBot
     end
 
     def notify(name, result_instance)
-      changed
-      notify_observers(name, result_instance)
+      @observer.update(name, result_instance)
     end
   end
 end
