@@ -1,12 +1,17 @@
 module FactoryBot
   # @api private
   class Trait
-    attr_reader :name, :definition
+    attr_reader :name, :uid, :definition
 
-    def initialize(name, &block)
+    delegate :add_callback, :declare_attribute, :to_create, :define_trait, :constructor,
+      :callbacks, :attributes, :klass, :klass=, to: :@definition
+
+    def initialize(name, **options, &block)
       @name = name.to_s
       @block = block
-      @definition = Definition.new(@name)
+      @uri_manager = FactoryBot::UriManager.new(names, paths: options[:uri_paths])
+
+      @definition = Definition.new(@name, uri_manager: @uri_manager)
       proxy = FactoryBot::DefinitionProxy.new(@definition)
 
       if block
@@ -15,12 +20,9 @@ module FactoryBot
     end
 
     def clone
-      Trait.new(name, &block)
+      Trait.new(name, uri_paths: definition.uri_manager.paths, &block)
     end
 
-    delegate :add_callback, :declare_attribute, :to_create, :define_trait, :constructor,
-      :callbacks, :attributes, :klass, :klass=, to: :@definition
-
     def names
       [@name]
     end
