@@ -17,4 +17,19 @@ describe "defining methods inside FactoryBot" do
       /Defining methods in blocks \(trait or factory\) is not supported \(generate_name\)/
     )
   end
+
+  it "accepts a method named :definition when set through :method_missing" do
+    define_model("User", definition: :string)
+
+    FactoryBot.define do
+      factory :user do
+        definition do
+          "Jester"
+        end
+      end
+    end
+
+    user = FactoryBot.build(:user)
+    expect(user.definition).to eq("Jester")
+  end
 end
