@@ -22,7 +22,7 @@ describe "register custom strategies" do
   before do
     FactoryBot.define do
       factory :named_object do
-        name "Great"
+        name { "Great" }
       end
     end
   end
@@ -65,7 +65,7 @@ describe "including FactoryBot::Syntax::Methods when custom strategies have been
   before do
     FactoryBot.define do
       factory :named_object do
-        name "Great"
+        name { "Great" }
       end
     end
   end
@@ -93,30 +93,30 @@ describe "associations without overriding :strategy" do
       end
 
       factory :user do
-        name "John Doe"
+        name { "John Doe" }
       end
     end
   end
 
-  context "when the :use_parent_strategy config option has not been enabled" do
-    before { FactoryBot.use_parent_strategy = nil }
-
+  context "when the :use_parent_strategy config option is set to false" do
     it "uses the overridden strategy on the association" do
       FactoryBot.register_strategy(:create, custom_strategy)
 
-      post = FactoryBot.build(:post)
-      expect(post.user.name).to eq "Custom strategy"
+      with_temporary_assignment(FactoryBot, :use_parent_strategy, false) do
+        post = FactoryBot.build(:post)
+        expect(post.user.name).to eq "Custom strategy"
+      end
     end
   end
 
-  context "when the :use_parent_strategy config option has been enabled" do
-    before { FactoryBot.use_parent_strategy = true }
-
+  context "when the :use_parent_strategy config option is set to true" do
     it "uses the parent strategy on the association" do
       FactoryBot.register_strategy(:create, custom_strategy)
 
-      post = FactoryBot.build(:post)
-      expect(post.user.name).to eq "John Doe"
+      with_temporary_assignment(FactoryBot, :use_parent_strategy, true) do
+        post = FactoryBot.build(:post)
+        expect(post.user.name).to eq "John Doe"
+      end
     end
   end
 end
@@ -137,7 +137,7 @@ describe "associations overriding :strategy" do
       end
 
       factory :user do
-        name "John Doe"
+        name { "John Doe" }
       end
     end
   end
