@@ -1,3 +1,4 @@
+# Set timeout when setting sequences
 require "rspec"
 require "rspec/its"
 
@@ -5,6 +6,8 @@ require "simplecov" if RUBY_ENGINE == "ruby"
 
 require "factory_bot"
 
+FactoryBot.sequence_setting_timeout = 0.5
+
 if RUBY_ENGINE == "jruby"
   # Workaround for issue in I18n/JRuby combo.
   # See https://github.com/jruby/jruby/issues/6547 and
